Functions
#################



ECG
-------

.. autofunction:: neurokit2.ecg_simulate

.. autofunction:: neurokit2.ecg_clean

.. autofunction:: neurokit2.ecg_findpeaks

.. autofunction:: neurokit2.ecg_rate

.. autofunction:: neurokit2.ecg_process

.. autofunction:: neurokit2.ecg_plot


RSP
-------

.. autofunction:: neurokit2.rsp_simulate

.. autofunction:: neurokit2.rsp_clean

.. autofunction:: neurokit2.rsp_findpeaks

.. autofunction:: neurokit2.rsp_rate

.. autofunction:: neurokit2.rsp_process

.. autofunction:: neurokit2.rsp_plot


EDA
-------

.. autofunction:: neurokit2.eda_simulate



EMG
-------

.. autofunction:: neurokit2.emg_simulate


General Signal Processing
--------------------------


Signal cleaning
""""""""""""""""

.. autofunction:: neurokit2.signal_distord

.. autofunction:: neurokit2.signal_binarize

.. autofunction:: neurokit2.signal_filter

.. autofunction:: neurokit2.signal_detrend

.. autofunction:: neurokit2.signal_smooth

.. autofunction:: neurokit2.signal_psd


Signal preprocessing
""""""""""""""""""""

.. autofunction:: neurokit2.signal_resample

.. autofunction:: neurokit2.signal_interpolate

.. autofunction:: neurokit2.signal_merge


Signal processing
""""""""""""""""""

.. autofunction:: neurokit2.signal_zerocrossings

.. autofunction:: neurokit2.signal_findpeaks

.. autofunction:: neurokit2.signal_plot







Events
-------

.. autofunction:: neurokit2.events_find

.. autofunction:: neurokit2.events_plot

.. autofunction:: neurokit2.events_to_mne



Read data
----------

.. autofunction:: neurokit2.read_acqknowledge
